@@ -1,12 +1,10 @@
 """
 The IndicatorBulkProcessor class manages the bulk process to send indicator to Vectra.
-It creates a .xml that contains the indicators to be sent.
-It sends indicators in batches of MAX_INDICATORS_PER_FILE.
+It creates a STIX file that contains the indicators to be sent.
 """
 
 import logging
-import os
-import time
+from datetime import datetime
 from os import path
 
 from cybox.core import Object
@@ -26,6 +24,8 @@ from src.vectra_client import VectraClient
 class IndicatorBulkProcessor:
     """Processes indicators."""
 
+    EXPIRATION_IN_DAYS = 30
+
     # pylint: disable=too-many-instance-attributes
     def __init__(self, configuration: Configuration):
         self.count = 0
@@ -35,35 +35,27 @@ class IndicatorBulkProcessor:
         self.vectra_client = VectraClient(
             configuration.get_vectra_fqdn(),
             configuration.get_vectra_api_key(),
-            configuration.get_vectra_threat_feed_ids(),
+            configuration.get_vectra_threat_feed_id(),
             configuration.get_vectra_ssl_verification()
         )
-        self.daily_stix_package = None
-        self.weekly_stix_package = None
-        self.daily_stix_file_path = configuration.get_daily_stix_file_path()
-        self.weekly_stix_file_path = configuration.get_weekly_stix_file_path()
-
-    def _clean_up_old_stix_files(self):
-        """
-        Removes old STIX files.
-        """
-        current_timestamp = time.time()
-        for stix_file in os.listdir(self.configuration.get_config_path()):
-            stix_file_path = os.path.join(self.configuration.get_config_path(), stix_file)
-            if stix_file[0:5] == 'stix-' and stix_file[-4:] == '.xml' and os.stat(
-                    stix_file_path).st_mtime < current_timestamp - 7 * 86400:
-                self.logger.info("Removing STIX file %s", stix_file_path)
-                os.remove(stix_file_path)
+        self.stix_package = None
+        self.stix_file_path = configuration.get_stix_file_path()
 
     def _create_stix_package(self):
         """
-        Creates the STIX package. If the daily and weekly STIX files exist, use those
-        as starting point.
+        Creates the STIX package. If the STIX file exist, use it as starting point.
         """
-        self.daily_stix_package = STIXPackage.from_xml(self.daily_stix_file_path) if path.exists(
-            self.daily_stix_file_path) else STIXPackage(stix_header=STIXHeader())
-        self.weekly_stix_package = STIXPackage.from_xml(self.weekly_stix_file_path) if path.exists(
-            self.weekly_stix_file_path) else STIXPackage(stix_header=STIXHeader())
+        self.stix_package = STIXPackage(stix_header=STIXHeader())
+        if path.exists(self.stix_file_path):
+            existing_indicator_count = 0
+            # Only use indicators that have not expired yet
+            for indicator in STIXPackage.from_xml(self.stix_file_path).indicators:
+                time_since_insertion = datetime.now().astimezone().replace(microsecond=0) - indicator.timestamp
+                if time_since_insertion.days < self.EXPIRATION_IN_DAYS:
+                    self.stix_package.add_indicator(indicator)
+                    existing_indicator_count += 1
+
+            self.logger.debug("Existing indicators: %s", existing_indicator_count)
 
     def add(self, indicator: dict) -> None:
         """
@@ -71,34 +63,35 @@ class IndicatorBulkProcessor:
         :param indicator: The indicator.
         """
         if not self.open:
-            self._clean_up_old_stix_files()
             self._create_stix_package()
             self.open = True
 
         self.logger.debug("Adding indicator: %s", indicator['value'])
         self.count += 1
-        self.daily_stix_package.add_indicator(self.parse_indicator_to_stix(indicator))
-        self.weekly_stix_package.add_indicator(self.parse_indicator_to_stix(indicator))
+        self.stix_package.add_indicator(self.parse_indicator_to_stix(indicator))
 
     def close(self) -> None:
         """
         Closes the bulk processor.
         """
         if self.count > 0:
+            self._save_file()
             self._send()
 
+    def _save_file(self) -> None:
+        """
+        Saves the indicators into a STIX file.
+        """
+        self.logger.info("Found new %s indicators", self.count)
+        # Write the STIX package to files
+        with open(self.stix_file_path, 'wb') as stix_file:
+            stix_file.write(self.stix_package.to_xml())
+
     def _send(self) -> None:
         """
         Sends the indicators and saves them to a STIX file.
         """
-        self.logger.info("Found new %s indicators", self.count)
-        # Write the STIX package to files
-        with open(self.daily_stix_file_path, 'wb') as stix_file:
-            stix_file.write(self.daily_stix_package.to_xml())
-        with open(self.weekly_stix_file_path, 'wb') as stix_file:
-            stix_file.write(self.weekly_stix_package.to_xml())
-        self.vectra_client.send_daily_indicators(self.daily_stix_file_path)
-        self.vectra_client.send_weekly_indicators(self.weekly_stix_file_path)
+        self.vectra_client.send_indicators(self.stix_file_path)
 
     @staticmethod
     def parse_indicator_to_stix(indicator: dict) -> Indicator:
@@ -128,7 +121,7 @@ class IndicatorBulkProcessor:
             cybox_object = Hostname()
             cybox_object.hostname_value = indicator['value']
 
-        stix_indicator = Indicator()
+        stix_indicator = Indicator(timestamp=indicator['discovered_at'])
         stix_indicator.title = 'Indicator of compromise'
         if indicator_type:
             stix_indicator.add_indicator_type(indicator_type)
