@@ -11,26 +11,19 @@ class VectraClient:
     """The VectraClient class provides the client to perform REST API requests to Vectra."""
     BASE_URI = 'https://%s/api/v2.1/threatFeeds'
 
-    def __init__(self, vectra_fqdn: str, vectra_key: str, vectra_threat_feeds, ssl_verification: bool = True):
+    def __init__(self, vectra_fqdn: str, vectra_key: str, vectra_threat_feed, ssl_verification: bool = True):
         self.logger = logging.getLogger('cyjax-vectra')
         self.base_url = self.BASE_URI % (vectra_fqdn,)
-        self.vectra_threat_feeds = vectra_threat_feeds
+        self.vectra_threat_feed = vectra_threat_feed
         self.headers = {'Authorization': 'token %s' % vectra_key}
         self.ssl_verification = ssl_verification
 
-    def send_daily_indicators(self, file_path):
+    def send_indicators(self, file_path):
         """
-        Sends daily indicators.
+        Sends indicators.
         @param file_path: :param file_path: The STIX file path.
         """
-        self._send(self.base_url + '/' + self.vectra_threat_feeds[0], file_path)
-
-    def send_weekly_indicators(self, file_path):
-        """
-        Sends weekly indicators.
-        @param file_path: :param file_path: The STIX file path.
-        """
-        self._send(self.base_url + '/' + self.vectra_threat_feeds[1], file_path)
+        self._send(self.base_url + '/' + self.vectra_threat_feed, file_path)
 
     def _send(self, url, file_path):
         """
@@ -58,5 +51,5 @@ class VectraClient:
         """
         Checks whether vectra push service can talk to vectra endpoint.
         """
-        return requests.request('GET', self.base_url + '/' + self.vectra_threat_feeds[0], headers=self.headers,
+        return requests.request('GET', self.base_url + '/' + self.vectra_threat_feed, headers=self.headers,
                                 verify=self.ssl_verification)
