@@ -1,7 +1,7 @@
 import unittest
 
-from src.configuration import CYJAX_API_KEY, VECTRA_FQDN, VECTRA_DAILY_THREAT_FEED_ID, \
-    VECTRA_WEEKLY_THREAT_FEED_ID, VECTRA_API_KEY, InvalidConfigurationException, \
+from src.configuration import CYJAX_API_KEY, VECTRA_FQDN, VECTRA_THREAT_FEED_ID, VECTRA_API_KEY, \
+    InvalidConfigurationException, \
     CONFIG_FILE_PATH
 from tests import create_mock_configuration
 
@@ -53,33 +53,19 @@ class ConfigurationTest(unittest.TestCase):
             self.configuration.validate()
         self.assertEqual('The Vectra API key cannot be empty.', str(context.exception))
 
-    def test_validate_with_no_vectra_daily_threat_feed_id(self):
-        del self.configuration.config[VECTRA_DAILY_THREAT_FEED_ID]
+    def test_validate_with_no_vectra_threat_feed_id(self):
+        del self.configuration.config[VECTRA_THREAT_FEED_ID]
 
         with self.assertRaises(InvalidConfigurationException) as context:
             self.configuration.validate()
-        self.assertEqual('The Vectra daily threat feed ID cannot be empty.', str(context.exception))
+        self.assertEqual('The Vectra threat feed ID cannot be empty.', str(context.exception))
 
-    def test_validate_with_no_vectra_weekly_threat_feed_id(self):
-        del self.configuration.config[VECTRA_WEEKLY_THREAT_FEED_ID]
+    def test_validate_with_empty_vectra_threat_feed_id(self):
+        self.configuration.config[VECTRA_THREAT_FEED_ID] = ''
 
         with self.assertRaises(InvalidConfigurationException) as context:
             self.configuration.validate()
-        self.assertEqual('The Vectra weekly threat feed ID cannot be empty.', str(context.exception))
-
-    def test_validate_with_empty_vectra_daily_threat_feed_id(self):
-        self.configuration.config[VECTRA_DAILY_THREAT_FEED_ID] = ''
-
-        with self.assertRaises(InvalidConfigurationException) as context:
-            self.configuration.validate()
-        self.assertEqual('The Vectra daily threat feed ID cannot be empty.', str(context.exception))
-
-    def test_validate_with_empty_vectra_weekly_threat_feed_id(self):
-        self.configuration.config[VECTRA_WEEKLY_THREAT_FEED_ID] = ''
-
-        with self.assertRaises(InvalidConfigurationException) as context:
-            self.configuration.validate()
-        self.assertEqual('The Vectra weekly threat feed ID cannot be empty.', str(context.exception))
+        self.assertEqual('The Vectra threat feed ID cannot be empty.', str(context.exception))
 
     def test_get_cyjax_api_key(self):
         self.assertEqual('test-cyjax-key', self.configuration.get_cyjax_api_key())
@@ -91,8 +77,7 @@ class ConfigurationTest(unittest.TestCase):
         self.assertEqual('test-vectra-key', self.configuration.get_vectra_api_key())
 
     def test_get_vectra_threat_feed_id(self):
-        self.assertEqual(('test-vectra-daily-feed-id', 'test-vectra-weekly-feed-id'),
-                         self.configuration.get_vectra_threat_feed_ids())
+        self.assertEqual('test-vectra-feed-id', self.configuration.get_vectra_threat_feed_id())
 
     def test_get_vectra_ssl_verification(self):
         self.assertEqual(False, self.configuration.get_vectra_ssl_verification())
