@@ -1,10 +1,11 @@
 import unittest
 from unittest.mock import MagicMock
 
+from stix.core import STIXPackage, STIXHeader
 from src.indicator_bulk_processor import IndicatorBulkProcessor
 from src.indicator_enum import URL_TYPE, IPV4_TYPE, IPV6_TYPE, DOMAIN_TYPE, HOSTNAME_TYPE
 from tests import create_mock_configuration
-
+from datetime import datetime, timedelta
 
 class IndicatorBulkProcessorTest(unittest.TestCase):
 
@@ -20,7 +21,7 @@ class IndicatorBulkProcessorTest(unittest.TestCase):
         indicator_bulk_processor = self._create_bulk_processor_mock()
         indicator_bulk_processor.add(self.indicator)
 
-        self.assertIsNotNone(indicator_bulk_processor.daily_stix_package)
+        self.assertIsNotNone(indicator_bulk_processor.stix_package)
         self.assertEqual(1, indicator_bulk_processor.count)
 
         indicator_bulk_processor._send.assert_not_called()
@@ -30,7 +31,7 @@ class IndicatorBulkProcessorTest(unittest.TestCase):
         indicator_bulk_processor.MAX_INDICATORS_PER_FILE = 1
         indicator_bulk_processor.add(self.indicator)
 
-        self.assertIsNotNone(indicator_bulk_processor.daily_stix_package)
+        self.assertIsNotNone(indicator_bulk_processor.stix_package)
         self.assertEqual(1, indicator_bulk_processor.count)
 
         indicator_bulk_processor._send.assert_not_called()
@@ -41,7 +42,7 @@ class IndicatorBulkProcessorTest(unittest.TestCase):
         indicator_bulk_processor.add(self.indicator)
         indicator_bulk_processor.close()
 
-        self.assertIsNotNone(indicator_bulk_processor.daily_stix_package)
+        self.assertIsNotNone(indicator_bulk_processor.stix_package)
         self.assertEqual(2, indicator_bulk_processor.count)
         indicator_bulk_processor._send.assert_called()
 
@@ -92,9 +93,59 @@ class IndicatorBulkProcessorTest(unittest.TestCase):
         self._assert_stix_indicator(IndicatorBulkProcessor.parse_indicator_to_stix(indicator), properties,
                                     watch_list_type)
 
-    def _create_indicator(self, indicator_type, value):
+    def test_reindex_indicators_within_thirty_days(self):
+
+        self._create_stix_file()
+
+        indicator_bulk_processor = self._create_bulk_processor_mock()
+        indicator_bulk_processor.add(self.indicator)
+        indicator_bulk_processor.close()
+
+        self.assertEqual(1, indicator_bulk_processor.count)
+        self.assertEqual(2, len(indicator_bulk_processor.stix_package.indicators))
+        self.assertCountEqual(['10.1.1.1', 'test.com'],
+                              IndicatorBulkProcessorTest._extract_indicator_values(indicator_bulk_processor.stix_package))
+
+        # assert generated stix file
+        stix_package_from_xml = STIXPackage.from_xml(self.configuration.get_stix_file_path())
+        self.assertEqual(2, len(stix_package_from_xml.indicators))
+        self.assertCountEqual(['10.1.1.1', 'test.com'],
+                              IndicatorBulkProcessorTest._extract_indicator_values(stix_package_from_xml))
+
+    @staticmethod
+    def _extract_indicator_values(stix_package):
+        indicators_values = []
+        for indicator in stix_package.indicators:
+            indicator_dict = indicator.to_dict()
+            if indicator_dict['observable']['object']['properties']['xsi:type'] == 'DomainNameObjectType':
+                indicators_values.append(indicator_dict['observable']['object']['properties']['value'])
+            elif indicator_dict['observable']['object']['properties']['xsi:type'] == 'AddressObjectType':
+                indicators_values.append(indicator_dict['observable']['object']['properties']['address_value'])
+
+        return indicators_values
+
+    def _create_stix_file(self):
+        # create existing file with indicators older and newer than 30 days
+        with open(self.configuration.get_stix_file_path(), 'wb') as stix_file:
+            stix_package = STIXPackage(stix_header=STIXHeader())
+
+            older_timestamp = (datetime.now().astimezone() - timedelta(days=40)).replace(microsecond=0).isoformat()
+            indicator_url_foo = self._create_indicator(HOSTNAME_TYPE, 'www.foo.com', timestamp=older_timestamp)
+            stix_package.add_indicator(IndicatorBulkProcessor.parse_indicator_to_stix(indicator_url_foo))
+
+            indicator_url_one = self._create_indicator(HOSTNAME_TYPE, 'www.one.com', timestamp=older_timestamp)
+            stix_package.add_indicator(IndicatorBulkProcessor.parse_indicator_to_stix(indicator_url_one))
+
+            recent_timestamp = datetime.now().astimezone().replace(microsecond=0).isoformat()
+            indicator_ip = self._create_indicator(IPV4_TYPE, '10.1.1.1', timestamp=recent_timestamp)
+
+            stix_package.add_indicator(IndicatorBulkProcessor.parse_indicator_to_stix(indicator_ip))
+            stix_file.write(stix_package.to_xml())
+            stix_file.close()
+
+    def _create_indicator(self, indicator_type, value, timestamp='2021-01-13T18:10:55+00:00'):
         return {'type': indicator_type, 'industry_type': ['Tourism', 'Aviation', 'Extremism', 'Adult'], 'ttp': [],
-                'value': value, 'handling_condition': 'GREEN', 'discovered_at': '2021-01-13T18:10:55+0000',
+                'value': value, 'handling_condition': 'GREEN', 'discovered_at': timestamp,
                 'uuid': '3d2c28a8-4a94-43cf-8305-b4e78199aec7', 'description': 'test industry verticals',
                 'source': 'https://csp.cyjax.com/report/incident/view?id=69105'}
 
@@ -105,6 +156,7 @@ class IndicatorBulkProcessorTest(unittest.TestCase):
         self.assertEqual('test industry verticals', stix_indicator['description'])
         self.assertEqual('3d2c28a8-4a94-43cf-8305-b4e78199aec7', stix_indicator['observable']['id'])
         self.assertEqual('stixVocabs:IndicatorTypeVocab-1.1', stix_indicator['indicator_types'][0]['xsi:type'])
+        self.assertEqual('2021-01-13T18:10:55+00:00', stix_indicator['timestamp'])
         self.assertEqual(watch_list_type, stix_indicator['indicator_types'][0]['value'])
         self.assertEqual(properties, stix_indicator['observable']['object']['properties'])
 
